@@ -6,21 +6,15 @@
  * with it, go get commit dcf99fe61379b78436c387ea3f89ebfd4ffaf635 of
  * bbsview_renderer.c and have fun.
  *
- * Copyright (c) 1996-2011 by the citadel.org team
+ * Copyright (c) 1996-2012 by the citadel.org team
  *
  * This program is open source software.  You can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #define RANGE 5
@@ -81,7 +75,9 @@ int bbsview_GetParamsGetServerCall(SharedMessageStatus *Stat,
 				   void **ViewSpecific, 
 				   long oper, 
 				   char *cmd, 
-				   long len)
+				   long len,
+				   char *filter,
+				   long flen)
 {
 	struct bbsview *BBS = malloc(sizeof(struct bbsview));
 	memset(BBS, 0, sizeof(struct bbsview));
@@ -417,6 +413,7 @@ InitModule_BBSVIEWRENDERERS
 		VIEW_BBS,
 		bbsview_GetParamsGetServerCall,
 		NULL,
+		NULL,
 		NULL, 
 		bbsview_LoadMsgFromServer,
 		bbsview_RenderView_or_Tail,
