@@ -1,21 +1,15 @@
 /*
  * Handles the HTML display of calendar items.
  *
- * Copyright (c) 1996-2011 by the citadel.org team
+ * Copyright (c) 1996-2012 by the citadel.org team
  *
  * This program is open source software.  You can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #include "webcit.h"
@@ -1429,7 +1423,9 @@ int calendar_GetParamsGetServerCall(SharedMessageStatus *Stat,
 				    void **ViewSpecific,
 				    long oper,
 				    char *cmd,
-				    long len)
+				    long len,
+				    char *filter,
+				    long flen)
 {
 	wcsession *WCC = WC;
 	calview *c;
