@@ -4,21 +4,15 @@
  * keep track of things.  If the HTTP request doesn't belong to any currently
  * active session, a new session is started.
  *
- * Copyright (c) 1996-2011 by the citadel.org team
+ * Copyright (c) 1996-2012 by the citadel.org team
  *
  * This program is open source software.  You can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #include "webcit.h"
@@ -267,7 +261,6 @@ int ReadHttpSubject(ParsedHttpHdrs *Hdr, StrBuf *Line, StrBuf *Buf)
 	void *vLine, *vHandler;
 	const char *Pos = NULL;
 
-
 	Hdr->HR.ReqLine = Line;
 	/* The requesttype... GET, POST... */
 	StrBufExtract_token(Buf, Hdr->HR.ReqLine, 0, ' ');
@@ -332,15 +325,24 @@ int ReadHttpSubject(ParsedHttpHdrs *Hdr, StrBuf *Line, StrBuf *Buf)
 	}
 
 	if (Hdr->HR.Handler != NULL) {
-		if ((Hdr->HR.Handler->Flags & BOGUS) != 0)
+		if ((Hdr->HR.Handler->Flags & BOGUS) != 0) {
 			return 1;
+		}
 		Hdr->HR.DontNeedAuth = (
 			((Hdr->HR.Handler->Flags & ISSTATIC) != 0) ||
 			((Hdr->HR.Handler->Flags & ANONYMOUS) != 0)
-			);
+		);
 	}
 	else {
-		Hdr->HR.DontNeedAuth = 1; /* Flat request? show him the login screen... */
+		/* If this is a "flat" request for the root, display the configured landing page. */
+		int return_value;
+		StrBuf *NewLine = NewStrBuf();
+		Hdr->HR.DontNeedAuth = 1;
+		StrBufAppendPrintf(NewLine, "GET /landing?go=%s HTTP/1.0", ChrPtr(Buf));
+		syslog(LOG_DEBUG, "Replacing with: %s", ChrPtr(NewLine));
+		return_value = ReadHttpSubject(Hdr, NewLine, Buf);
+		FreeStrBuf(&NewLine);
+		return return_value;
 	}
 
 	return 0;
@@ -713,7 +715,8 @@ const char *ReqStrs[eNONE] = {
 	"DELETE",
 	"HEAD",
 	"MOVE",
-	"COPY"
+	"COPY",
+	"REPORT"
 };
 
 void
@@ -759,6 +762,10 @@ ServerStartModule_CONTEXT
 	v = malloc(sizeof(long));
 	*v = eCOPY;
 	Put(HttpReqTypes, HKEY("COPY"), v, NULL);
+
+	v = malloc(sizeof(long));
+	*v = eREPORT;
+	Put(HttpReqTypes, HKEY("REPORT"), v, NULL);
 }
 
 void 
