@@ -2,20 +2,15 @@
  * Output an HTML message, modifying it slightly to make sure it plays nice
  * with the rest of our web framework.
  *
- * Copyright (c) 2005-2011 by the citadel.org team
+ * Copyright (c) 2005-2012 by the citadel.org team
  *
  * This program is open source software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
  */
 
 #include "webcit.h"
@@ -400,7 +395,9 @@ void output_html(const char *supplied_charset, int treat_as_wiki, int msgnum, St
 				&& (strncasecmp(ptr, "<a href=\"knrooms?", 17))
 			) {
 				content_length += 64;
-				StrBufAppendPrintf(converted_msg, "<a href=\"wiki?page=");
+				StrBufAppendPrintf(converted_msg, "<a href=\"wiki?go=");
+				StrBufUrlescAppend(converted_msg, WC->CurRoom.name, NULL);
+				StrBufAppendPrintf(converted_msg, "?page=");
 				ptr = &ptr[9];
 			}
 			else {
