@@ -1,6 +1,4 @@
 /* 
- * $Id$
- *
  * Functions which handle Internet domain configuration etc.
  */
 
@@ -21,14 +19,9 @@ typedef enum _e_cfg {
 	ic_max
 } ECfg;
 
-typedef struct _ConstStrBuf {
-	const char *name;
-	size_t len;
-} ConstStrBuf;
-
 
   /* These are server config keywords; do not localize! */
-ConstStrBuf CfgNames[] = {
+ConstStr CfgNames[] = {
 	{ HKEY("localhost") },
 	{ HKEY("directory") },
 	{ HKEY("smarthost") },
@@ -57,9 +50,9 @@ void load_inetconf(void)
 	
 	WCC->InetCfg = NewHash(1, NULL);
 
-	for (i = 0; i < (sizeof(CfgNames) / sizeof(ConstStrBuf)); i++) {
+	for (i = 0; i < (sizeof(CfgNames) / sizeof(ConstStr)); i++) {
 		Hash = NewHash(1, NULL);
-		Put(WCC->InetCfg, CfgNames[i].name, CfgNames[i].len, Hash, HDeleteHash);
+		Put(WCC->InetCfg, CKEY(CfgNames[i]), Hash, HDeleteHash);
 	}
 
 	serv_printf("CONF GETSYS|application/x-citadel-internet-config");
@@ -80,7 +73,7 @@ void load_inetconf(void)
 			GetHash(WCC->InetCfg, ChrPtr(CfgToken), StrLength(CfgToken), &vHash);
 			Hash = (HashList*) vHash;
 			if (Hash == NULL) {
-				lprintf(1, "ERROR Loading inet config line: [%s]\n", 
+				syslog(1, "ERROR Loading inet config line: [%s]\n", 
 					ChrPtr(Buf));
 				FreeStrBuf(&Value);
 				continue;
@@ -114,7 +107,7 @@ void new_save_inetconf(void) {
 	GetHash(WCC->InetCfg, ChrPtr(eType), StrLength(eType), &vHash);
 	Hash = (HashList*) vHash;
 	if (Hash == NULL) {
-		StrBufPrintf(WCC->ImportantMsg, _("Invalid Parameter"));
+		AppendImportantMessage(_("Invalid Parameter"), -1);
 		url_do_template();
 		return;
 	}
@@ -123,20 +116,21 @@ void new_save_inetconf(void) {
 		eNum = sbstr("ename");
 		if (!GetHash(Hash, ChrPtr(eNum), StrLength(eNum), &vStr) ||
 		    (vStr == NULL)) {
-			StrBufPrintf(WCC->ImportantMsg, _("Invalid Parameter"));
+			AppendImportantMessage(_("Invalid Parameter"), -1);
 			url_do_template();
 			return;
 		}
 
 		Str = (StrBuf*)vStr;
-		StrBufPrintf(WCC->ImportantMsg, _("%s has been deleted."), ChrPtr(Str));
+		AppendImportantMessage(SKEY(Str));
+		AppendImportantMessage(_(" has been deleted."), -1);
 		FlushStrBuf(Str);	
 	}
 	else if (!strcasecmp(bstr("oper"), "add")) {
 		StrBuf *name;
 		eName = sbstr("ename");
 		if (eName == NULL) {
-			StrBufPrintf(WCC->ImportantMsg, _("Invalid Parameter"));
+			AppendImportantMessage(_("Invalid Parameter"), -1);
 			url_do_template();
 			return;
 		}
@@ -146,24 +140,23 @@ void new_save_inetconf(void) {
 		name = NewStrBufDup(eName);
 		StrBufTrim(name);
 		Put(Hash, nnn, nUsed, name, HFreeStrBuf); 
-		StrBufPrintf(WCC->ImportantMsg, "%s %s", 
-			     /*<domain> added status message*/ _("added."), 
-			     ChrPtr(eName));
+		AppendImportantMessage(SKEY(eName));
+		AppendImportantMessage( /*<domain> added status message*/ _(" added."), -1); 
 	}
 
 	Buf = NewStrBuf();
 	serv_printf("CONF PUTSYS|application/x-citadel-internet-config");
 	StrBuf_ServGetln(Buf);
 	if (GetServerStatus(Buf, NULL) == 4) {
-		for (i = 0; i < (sizeof(CfgNames) / sizeof(ConstStrBuf)); i++) {
+		for (i = 0; i < (sizeof(CfgNames) / sizeof(ConstStr)); i++) {
 			HashPos *where;
 			const char *Key;
 			long KeyLen;
 
-			GetHash(WCC->InetCfg, CfgNames[i].name, CfgNames[i].len, &vHash);
+			GetHash(WCC->InetCfg, CKEY(CfgNames[i]), &vHash);
 			Hash = (HashList*) vHash;
 			if (Hash == NULL) {
-				sprintf(WC->ImportantMessage, _("Invalid Parameter"));
+				AppendImportantMessage(_("Invalid Parameter"), -1);
 				url_do_template();
 				return;
 			}
@@ -174,7 +167,7 @@ void new_save_inetconf(void) {
 					if ((Str!= NULL) && (StrLength(Str) > 0))
 						serv_printf("%s|%s", 
 							    ChrPtr(Str),
-							    CfgNames[i].name); 
+							    CfgNames[i].Key); 
 				}
 				DeleteHashPos(&where);
 			}			
@@ -186,11 +179,6 @@ void new_save_inetconf(void) {
 	url_do_template();
 }
 
-void InetCfgSubst(StrBuf *TemplBuffer, WCTemplputParams *TP)
-{
-	SVPutBuf("SERVCFG:INET:HOSTNAME", CTX, 1);
-}
-
 void DeleteInetConfHash(StrBuf *Target, WCTemplputParams *TP)
 {
 	wcsession *WCC = WC;
@@ -209,7 +197,7 @@ HashList *GetInetConfHash(StrBuf *Target, WCTemplputParams *TP)
 	if (WCC->InetCfg == NULL)
 		load_inetconf();
 	GetHash(WCC->InetCfg, TKEY(5), &vHash);
-	svprintf(HKEY("SERVCFG:INET:TYPE"), WCS_STRING, TP->Tokens->Params[5]->Start);
+	PutBstr(HKEY("__SERVCFG:INET:TYPE"), NewStrBufPlain(TKEY(5)));
 	return vHash;
 }
 
@@ -218,6 +206,6 @@ InitModule_INETCONF
 (void)
 {
 	WebcitAddUrlHandler(HKEY("save_inetconf"), "", 0, new_save_inetconf, 0);
-	RegisterIterator("SERVCFG:INET", 1, NULL, GetInetConfHash, InetCfgSubst, NULL, CTX_INETCFG, CTX_NONE, IT_NOFLAG);
+	RegisterIterator("SERVCFG:INET", 1, NULL, GetInetConfHash, NULL, NULL, CTX_STRBUF, CTX_NONE, IT_NOFLAG);
 	RegisterNamespace("SERVCFG:FLUSHINETCFG",0, 0, DeleteInetConfHash, NULL, CTX_NONE);
 }
