@@ -1,21 +1,15 @@
 /*
  * Functions which deal with the fetching and displaying of messages.
  *
- * Copyright (c) 1996-2011 by the citadel.org team
+ * Copyright (c) 1996-2012 by the citadel.org team
  *
  * This program is open source software.  You can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #include "webcit.h"
@@ -43,6 +37,15 @@ typedef struct _MsgPartEvaluatorStruct {
 	MsgPartEvaluatorFunc f;
 } MsgPartEvaluatorStruct;
 
+void fixview()
+{
+	/* workaround for json listview; its not useable directly */
+	if (WC->CurRoom.view == VIEW_JSON_LIST) {
+		StrBuf *View = NewStrBuf();
+		StrBufPrintf(View, "%d", VIEW_MAILBOX);
+		putbstr("view", View);;
+	}
+}
 int load_message(message_summary *Msg, 
 		 StrBuf *FoundCharset,
 		 StrBuf **Error)
@@ -529,7 +532,8 @@ message_summary *ReadOneMessageSummary(StrBuf *RawMessage, const char *DefaultSu
  *
  * servcmd:		the citadel command to send to the citserver
  */
-int load_msg_ptrs(const char *servcmd, 
+int load_msg_ptrs(const char *servcmd,
+		  const char *filter,
 		  SharedMessageStatus *Stat, 
 		  load_msg_ptrs_detailheaders LH)
 {
@@ -540,6 +544,7 @@ int load_msg_ptrs(const char *servcmd,
 	int n;
 	int skipit;
 	const char *Ptr = NULL;
+	int StatMajor;
 
 	Stat->lowest_found = LONG_MAX;
 	Stat->highest_found = LONG_MIN;
@@ -552,7 +557,21 @@ int load_msg_ptrs(const char *servcmd,
 	Buf = NewStrBuf();
 	serv_puts(servcmd);
 	StrBuf_ServGetln(Buf);
-	if (GetServerStatus(Buf, NULL) != 1) {
+	StatMajor = GetServerStatus(Buf, NULL);
+	switch (StatMajor) {
+	case 1:
+		break;
+	case 8:
+		if (filter != NULL) {
+			serv_puts(filter);
+                        serv_puts("000");
+			break;
+		}
+		/* fall back to empty filter in case of we were fooled... */
+		serv_puts("");
+		serv_puts("000");
+		break;
+	default:
 		FreeStrBuf(&Buf);
 		return (Stat->nummsgs);
 	}
@@ -672,6 +691,8 @@ typedef struct _RoomRenderer{
 	int RoomType;
 
 	GetParamsGetServerCall_func GetParamsGetServerCall;
+	
+	PrintViewHeader_func PrintPageHeader;
 	PrintViewHeader_func PrintViewHeader;
 	LoadMsgFromServer_func LoadMsgFromServer;
 	RenderView_or_Tail_func RenderView_or_Tail;
@@ -692,6 +713,7 @@ void readloop(long oper, eCustomRoomRenderer ForceRenderer)
 	void *vMsg;
 	message_summary *Msg;
 	char cmd[256] = "";
+	char filter[256] = "";
 	int i, r;
 	wcsession *WCC = WC;
 	HashPos *at;
@@ -705,18 +727,8 @@ void readloop(long oper, eCustomRoomRenderer ForceRenderer)
 		WCC->CurRoom.view = VIEW_MAILBOX;
 	}
 
-	if (havebstr("is_ajax") && (1 == (ibstr("is_ajax")))) {
-		WCC->is_ajax = 1;
-	}
-
-	if ((oper == do_search) && (WCC->CurRoom.view == VIEW_WIKI)) {
-		display_wiki_pagelist();
-		return;
-	}
-
-	if (WCC->CurRoom.view == VIEW_WIKI) {
-		http_redirect("wiki?page=home");
-		return;
+	if (havebstr("view")) {
+		WCC->CurRoom.view = ibstr("view");
 	}
 
 	memset(&Stat, 0, sizeof(SharedMessageStatus));
@@ -736,22 +748,23 @@ void readloop(long oper, eCustomRoomRenderer ForceRenderer)
 	}
 
 	ViewMsg = (RoomRenderer*) vViewMsg;
-	if (!WCC->is_ajax) {
+	if (ViewMsg->PrintPageHeader == NULL)
 		output_headers(1, 1, 1, 0, 0, 0);
-	} else if (WCC->CurRoom.view == VIEW_MAILBOX) {
-		jsonMessageListHdr();
-	}
+	else 
+		ViewMsg->PrintPageHeader(&Stat, ViewSpecific);
 
 	if (ViewMsg->GetParamsGetServerCall != NULL) {
 		r = ViewMsg->GetParamsGetServerCall(
 		       &Stat,
 		       &ViewSpecific,
 		       oper,
-		       cmd, sizeof(cmd)
+		       cmd, sizeof(cmd),
+		       filter, sizeof(filter)
 		);
 	} else {
 		r = 0;
 	}
+
 	switch(r)
 	{
 	case 400:
@@ -764,8 +777,12 @@ void readloop(long oper, eCustomRoomRenderer ForceRenderer)
 	default:
 		break;
 	}
-	if (!IsEmptyStr(cmd))
-		Stat.nummsgs = load_msg_ptrs(cmd, &Stat, ViewMsg->LHParse);
+	if (!IsEmptyStr(cmd)) {
+		const char *p = NULL;
+		if (!IsEmptyStr(filter))
+			p = filter;
+		Stat.nummsgs = load_msg_ptrs(cmd, p, &Stat, ViewMsg->LHParse);
+	}
 
 	if (Stat.sortit) {
 		CompareFunc SortIt;
@@ -882,7 +899,9 @@ void post_mime_to_server(void) {
 	}
 
 	/* Only do multipart/alternative for mailboxes.  BBS and Wiki rooms don't need it. */
-	if (WC->CurRoom.view == VIEW_MAILBOX) {
+	if ((WCC->CurRoom.view == VIEW_MAILBOX) ||
+	    (WCC->CurRoom.view == VIEW_JSON_LIST))
+	{
 		include_text_alt = 1;
 	}
 
@@ -1003,7 +1022,7 @@ void post_message(void)
 		StrBuf *Recp = NULL; 
 		StrBuf *Cc = NULL;
 		StrBuf *Bcc = NULL;
-		const StrBuf *Wikipage = NULL;
+		char *wikipage = NULL;
 		const StrBuf *my_email_addr = NULL;
 		StrBuf *CmdBuf = NULL;
 		StrBuf *references = NULL;
@@ -1058,14 +1077,15 @@ void post_message(void)
 		FreeStrBuf(&EmailAddress);
 		FreeStrBuf(&EncBuf);
 
-		Wikipage = sbstr("page");
+		wikipage = strdup(bstr("page"));
+		str_wiki_index(wikipage);
 		my_email_addr = sbstr("my_email_addr");
 		
 		HeaderLen = StrLength(Recp) + 
 			StrLength(encoded_subject) +
 			StrLength(Cc) +
 			StrLength(Bcc) + 
-			StrLength(Wikipage) +
+			strlen(wikipage) +
 			StrLength(my_email_addr) + 
 			StrLength(references);
 		CmdBuf = NewStrBufPlain(NULL, sizeof (CMD) + HeaderLen);
@@ -1077,11 +1097,12 @@ void post_message(void)
 			     ChrPtr(display_name),
 			     saving_to_drafts?"":ChrPtr(Cc),
 			     saving_to_drafts?"":ChrPtr(Bcc),
-			     ChrPtr(Wikipage),
+			     wikipage,
 			     ChrPtr(my_email_addr),
 			     ChrPtr(references));
 		FreeStrBuf(&references);
 		FreeStrBuf(&encoded_subject);
+		free(wikipage);
 
 		if ((HeaderLen + StrLength(sbstr("msgtext")) < 10) && 
 		    (GetCount(WCC->attachments) == 0)){
@@ -1106,13 +1127,14 @@ void post_message(void)
 						serv_printf("Cc: %s", ChrPtr(Cc));
 						serv_printf("Bcc: %s", ChrPtr(Bcc));
 					} else {
-						serv_printf("X-Citadel-Room: %s", ChrPtr(WC->CurRoom.name));
+						serv_printf("X-Citadel-Room: %s", ChrPtr(WCC->CurRoom.name));
 					}
 				}
 				post_mime_to_server();
 				if (saving_to_drafts) {
 					AppendImportantMessage(_("Message has been saved to Drafts.\n"), -1);
 					gotoroom(WCC->CurRoom.name);
+					fixview();
 					readloop(readnew, eUseDefault);
 					FreeStrBuf(&Buf);
 					return;
@@ -1164,6 +1186,7 @@ void post_message(void)
 	 *  Otherwise, just go to the "read messages" loop.
 	 */
 	else {
+		fixview();
 		readloop(readnew, eUseDefault);
 	}
 }
@@ -1293,14 +1316,28 @@ long l_msgn;
 long l_from;
 long l_rcpt;
 long l_cccc;
+long l_replyto;
 long l_node;
 long l_rfca;
 
+const char *ReplyToModeStrings [3] = {
+	"reply",
+	"replyalle",
+	"forward"
+};
+typedef enum _eReplyToNodes {
+	eReply,
+	eReplyAll,
+	eForward
+}eReplyToNodes;
+	
 /*
  * display the message entry screen
  */
 void display_enter(void)
 {
+	const char *ReplyingModeStr;
+	eReplyToNodes ReplyMode = eReply;
 	StrBuf *Line;
 	long Result;
 	int rc;
@@ -1335,6 +1372,7 @@ void display_enter(void)
 	}
 	else if (rc != 2) {		/* Any other error means that we cannot continue */
 		rc = GetServerStatusMsg(Line, &Result, 0, 2);
+		fixview();
 		readloop(readnew, eUseDefault);
 		FreeStrBuf(&Line);
 		return;
@@ -1376,6 +1414,15 @@ void display_enter(void)
 	}
 
 
+	ReplyingModeStr = bstr("replying_mode");
+	if (ReplyingModeStr != NULL) for (i = 0; i < 3; i++) {
+			if (strcmp(ReplyingModeStr, ReplyToModeStrings[i]) == 0) {
+				ReplyMode = (eReplyToNodes) i;
+				break;
+			}
+		}
+		
+
 	/*
 	 * If the "replying_to" variable is set, it refers to a message
 	 * number from which we must extract some header fields...
@@ -1390,6 +1437,7 @@ void display_enter(void)
 		StrBuf *rfca = NULL;
 		StrBuf *rcpt = NULL;
 		StrBuf *cccc = NULL;
+		StrBuf *replyto = NULL;
 		serv_printf("MSG0 %ld|1", replying_to);	
 
 		StrBuf_ServGetln(Line);
@@ -1409,7 +1457,7 @@ void display_enter(void)
 					StrBuf *subj = NewStrBuf();
 					StrBuf *FlatSubject;
 
-					if (!strcasecmp(bstr("replying_mode"), "forward")) {
+					if (ReplyMode == eForward) {
 						if (strncasecmp(ChrPtr(Line) + 5, "Fw:", 3)) {
 							StrBufAppendBufPlain(subj, HKEY("Fw: "), 0);
 						}
@@ -1473,7 +1521,9 @@ void display_enter(void)
 				else if (which == l_node) {
 					node = NewStrBufPlain(ChrPtr(Line) + 5, StrLength(Line) - 5);
 				}
-				
+				else if (which == l_replyto) {
+					replyto = NewStrBufPlain(ChrPtr(Line) + 5, StrLength(Line) - 5);
+				}				
 				else if (which == l_rfca) {
 					StrBuf *FlatRFCA;
 					rfca = NewStrBufPlain(ChrPtr(Line) + 5, StrLength(Line) - 5);
@@ -1504,11 +1554,14 @@ void display_enter(void)
 		/*
 		 * If this is a Reply or a ReplyAll, copy the sender's email into the To: field
 		 */
-		if (	(!strcasecmp(bstr("replying_mode"), "reply"))
-			|| (!strcasecmp(bstr("replying_mode"), "replyall"))
-		) {
+		if ((ReplyMode == eReply) || (ReplyMode == eReplyAll))
+		{
 			StrBuf *to_rcpt;
-			if (StrLength(rfca) > 0) {
+			if ((StrLength(replyto) > 0) && (ReplyMode == eReplyAll)) {
+				to_rcpt = NewStrBuf();
+				StrBufAppendBuf(to_rcpt, replyto, 0);
+			}
+			else if (StrLength(rfca) > 0) {
 				to_rcpt = NewStrBuf();
 				StrBufAppendBuf(to_rcpt, from, 0);
 				StrBufAppendBufPlain(to_rcpt, HKEY(" <"), 0);
@@ -1519,7 +1572,7 @@ void display_enter(void)
 				to_rcpt =  from;
 				from = NULL;
 				if (	(StrLength(node) > 0)
-					&& (strcasecmp(ChrPtr(node), ChrPtr(WC->serv_info->serv_nodename)))
+					&& (strcasecmp(ChrPtr(node), ChrPtr(WCC->serv_info->serv_nodename)))
 				) {
 					StrBufAppendBufPlain(to_rcpt, HKEY(" @ "), 0);
 					StrBufAppendBuf(to_rcpt, node, 0);
@@ -1531,11 +1584,12 @@ void display_enter(void)
 		/*
 		 * Only if this is a ReplyAll, copy all recipients into the Cc: field
 		 */
-		if (	(!strcasecmp(bstr("replying_mode"), "replyall"))
-		) {
+		if (ReplyMode == eReplyAll)
+		{
 			StrBuf *cc_rcpt = rcpt;
 			rcpt = NULL;
-			if (StrLength(cccc) > 0) {
+			if ((StrLength(cccc) > 0) && (StrLength(replyto) == 0))
+			{
 				if (cc_rcpt != NULL)  {
 					StrBufAppendPrintf(cc_rcpt, ", ");
 					StrBufAppendBuf(cc_rcpt, cccc, 0);
@@ -1565,14 +1619,15 @@ void display_enter(void)
 		const StrBuf *Recp = NULL; 
 		const StrBuf *Cc = NULL;
 		const StrBuf *Bcc = NULL;
-		const StrBuf *Wikipage = NULL;
+		char *wikipage = NULL;
 		StrBuf *CmdBuf = NULL;
 		const char CMD[] = "ENT0 0|%s|%d|0||%s||%s|%s|%s";
 		
 		Recp = sbstr("recp");
 		Cc = sbstr("cc");
 		Bcc = sbstr("bcc");
-		Wikipage = sbstr("page");
+		wikipage = strdup(bstr("page"));
+		str_wiki_index(wikipage);
 		
 		CmdBuf = NewStrBufPlain(NULL, 
 					sizeof (CMD) + 
@@ -1580,7 +1635,7 @@ void display_enter(void)
 					StrLength(display_name) +
 					StrLength(Cc) +
 					StrLength(Bcc) + 
-					StrLength(Wikipage));
+					strlen(wikipage));
 
 		StrBufPrintf(CmdBuf, 
 			     CMD,
@@ -1589,9 +1644,11 @@ void display_enter(void)
 			     ChrPtr(display_name),
 			     ChrPtr(Cc), 
 			     ChrPtr(Bcc), 
-			     ChrPtr(Wikipage));
+			     wikipage
+		);
 		serv_puts(ChrPtr(CmdBuf));
 		StrBuf_ServGetln(CmdBuf);
+		free(wikipage);
 
 		rc = GetServerStatusMsg(CmdBuf, &Result, 0, 0);
 
@@ -1603,6 +1660,7 @@ void display_enter(void)
 		else if (rc != 2) {	/* Any other error means that we cannot continue */
 			AppendImportantMessage(ChrPtr(CmdBuf) + 4, StrLength(CmdBuf) - 4);
 			FreeStrBuf(&CmdBuf);
+			fixview();
 			readloop(readnew, eUseDefault);
 			return;
 		}
@@ -1641,6 +1699,8 @@ void delete_msg(void)
 	StrBuf_ServGetln(Line);
 	GetServerStatusMsg(Line, NULL, 1, 0);
 
+	fixview();
+
 	readloop(readnew, eUseDefault);
 }
 
@@ -1665,6 +1725,7 @@ void move_msg(void)
 		AppendImportantMessage(_("The message was not moved."), -1);
 	}
 
+	fixview();
 	readloop(readnew, eUseDefault);
 }
 
@@ -1721,6 +1782,7 @@ void postpart(StrBuf *partnum, StrBuf *filename, int force_download)
 void mimepart(int force_download)
 {
 	long msgnum;
+	long ErrorDetail;
 	StrBuf *att;
 	wcsession *WCC = WC;
 	StrBuf *Buf;
@@ -1734,7 +1796,7 @@ void mimepart(int force_download)
 
 	serv_printf("OPNA %ld|%s", msgnum, ChrPtr(att));
 	StrBuf_ServGetln(Buf);
-	if (GetServerStatus(Buf, NULL) == 2) {
+	if (GetServerStatus(Buf, &ErrorDetail) == 2) {
 		StrBufCutLeft(Buf, 4);
 		bytes = StrBufExtract_long(Buf, 0, '|');
 		if (!force_download) {
@@ -1758,7 +1820,23 @@ void mimepart(int force_download)
 		http_transmit_thing(CT, 0);
 	} else {
 		StrBufCutLeft(Buf, 4);
-		hprintf("HTTP/1.1 404 %s\n", ChrPtr(Buf));
+		switch (ErrorDetail) {
+		default:
+		case ERROR + MESSAGE_NOT_FOUND:
+			hprintf("HTTP/1.1 404 %s\n", ChrPtr(Buf));
+			break;
+		case ERROR + NOT_LOGGED_IN:
+			hprintf("HTTP/1.1 401 %s\n", ChrPtr(Buf));
+			break;
+
+		case ERROR + HIGHER_ACCESS_REQUIRED:
+			hprintf("HTTP/1.1 403 %s\n", ChrPtr(Buf));
+			break;
+		case ERROR + INTERNAL_ERROR:
+		case ERROR + TOO_BIG:
+			hprintf("HTTP/1.1 500 %s\n", ChrPtr(Buf));
+			break;
+		}
 		output_headers(0, 0, 0, 0, 0, 0);
 		hprintf("Content-Type: text/plain\r\n");
 		begin_burst();
@@ -1877,31 +1955,23 @@ void h_do_search(void) { readloop(do_search, eUseDefault);}
 void h_readgt(void) { readloop(readgt, eUseDefault);}
 void h_readlt(void) { readloop(readlt, eUseDefault);}
 
-void jsonMessageListHdr(void) 
-{
-	/* TODO: make a generic function */
-	hprintf("HTTP/1.1 200 OK\r\n");
-	hprintf("Content-type: application/json; charset=utf-8\r\n");
-	hprintf("Server: %s / %s\r\n", PACKAGE_STRING, ChrPtr(WC->serv_info->serv_software));
-	hprintf("Connection: close\r\n");
-	hprintf("Pragma: no-cache\r\nCache-Control: no-store\r\nExpires:-1\r\n");
-	begin_burst();
-}
 
 
 /* Output message list in JSON format */
 void jsonMessageList(void) {
+	StrBuf *View = NewStrBuf();
 	const StrBuf *room = sbstr("room");
 	long oper = (havebstr("query")) ? do_search : readnew;
-	WC->is_ajax = 1; 
+	StrBufPrintf(View, "%d", VIEW_JSON_LIST);
+	putbstr("view", View);; 
 	gotoroom(room);
 	readloop(oper, eUseDefault);
-	WC->is_ajax = 0;
 }
 
 void RegisterReadLoopHandlerset(
 	int RoomType,
 	GetParamsGetServerCall_func GetParamsGetServerCall,
+	PrintViewHeader_func PrintPageHeader,
 	PrintViewHeader_func PrintViewHeader,
 	load_msg_ptrs_detailheaders LH,
 	LoadMsgFromServer_func LoadMsgFromServer,
@@ -1915,6 +1985,7 @@ void RegisterReadLoopHandlerset(
 
 	Handler->RoomType = RoomType;
 	Handler->GetParamsGetServerCall = GetParamsGetServerCall;
+	Handler->PrintPageHeader = PrintPageHeader;
 	Handler->PrintViewHeader = PrintViewHeader;
 	Handler->LoadMsgFromServer = LoadMsgFromServer;
 	Handler->RenderView_or_Tail = RenderView_or_Tail;
@@ -1981,6 +2052,7 @@ InitModule_MSG
 	l_from = FourHash("from", 4);
 	l_rcpt = FourHash("rcpt", 4);
 	l_cccc = FourHash("cccc", 4);
+	l_replyto = FourHash("rep2", 4);
 	l_node = FourHash("node", 4);
 	l_rfca = FourHash("rfca", 4);
 
