@@ -416,7 +416,9 @@ int notes_GetParamsGetServerCall(SharedMessageStatus *Stat,
 				 void **ViewSpecific, 
 				 long oper, 
 				 char *cmd, 
-				 long len)
+				 long len,
+				 char *filter,
+				 long flen)
 {
 	strcpy(cmd, "MSGS ALL");
 	Stat->maxmsgs = 32767;
@@ -441,6 +443,7 @@ InitModule_NOTES
 		notes_GetParamsGetServerCall,
 		NULL,
 		NULL,
+		NULL,
 		notes_LoadMsgFromServer,
 		NULL,
 		notes_Cleanup);
