@@ -1,17 +1,18 @@
 
-
-#define PRF_STRING 1
-#define PRF_INT 2
-#define PRF_QP_STRING 3
-#define PRF_YESNO 4
-
+typedef enum _ePrefType{
+	PRF_UNSET = 0,
+	PRF_STRING = 1,
+	PRF_INT = 2,
+	PRF_QP_STRING = 3,
+	PRF_YESNO = 4
+} ePrefType;
 
 
 typedef void (*PrefEvalFunc)(StrBuf *Preference, long lvalue); 
 
 void _RegisterPreference(const char *Setting, long SettingLen, 
 			 const char *PrefStr, 
-			 long Type, 
+			 ePrefType Type, 
 			 PrefEvalFunc OnLoad, 
 			 const char *OnLoadName);
 
@@ -51,3 +52,5 @@ const StrBuf *get_X_PREFS(const char *key, size_t keylen,
 
 #define set_x_pref(a, b, c) set_ROOM_PREFS(a, sizeof(a) - 1, b, sizeof(b) - 1, c, d)
 void set_X_PREFS(const char *key, size_t keylen, const char *xkey, size_t xkeylen, StrBuf *value, int save_to_server);
+
+int goto_config_room(StrBuf *Buf, folder *room);
