@@ -1,12 +1,20 @@
 /*
  * Administrative screen for site-wide configuration
+ *
+ * Copyright (c) 1996-2012 by the citadel.org team
+ *
+ * This program is open source software.  You can redistribute it and/or
+ * modify it under the terms of the GNU General Public License, version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  */
 
-
 #include "webcit.h"
 #include "webserver.h"
 
-
 HashList *ZoneHash = NULL;
 
 ConstStr ExpirePolicyString = {CStrOf(roompolicy)     };
@@ -28,7 +36,6 @@ void LoadExpirePolicy(GPEXWhichPolicy which)
 	serv_printf("GPEX %s", ExpirePolicyStrings[which][0].Key);
 	Buf = NewStrBuf();
 	StrBuf_ServGetln(Buf);
-	WCC->Policy[which].loaded = 1;
 	if (GetServerStatus(Buf, &State) == 2) {
 		Pos = ChrPtr(Buf) + 4;
 		WCC->Policy[which].expire_mode = StrBufExtractNext_long(Buf, &Pos, '|');
@@ -66,7 +73,7 @@ int ConditionalExpire(StrBuf *Target, WCTemplputParams *TP)
 	which = GetTemplateTokenNumber(Target, TP, 2, 0);
 	CompareWith = GetTemplateTokenNumber(Target, TP, 3, 0);
 
-	if (WCC->Policy[which].loaded == 0) LoadExpirePolicy(which);
+	LoadExpirePolicy(which);
 	
 	return WCC->Policy[which].expire_mode == CompareWith;
 }
@@ -77,7 +84,7 @@ void tmplput_ExpireValue(StrBuf *Target, WCTemplputParams *TP)
 	wcsession *WCC = WC;
 		
 	which = GetTemplateTokenNumber(Target, TP, 0, 0);
-	if (WCC->Policy[which].loaded == 0) LoadExpirePolicy(which);
+	LoadExpirePolicy(which);
 	StrBufAppendPrintf(Target, "%d", WCC->Policy[which].expire_value);
 }
 
@@ -88,12 +95,11 @@ void tmplput_ExpireMode(StrBuf *Target, WCTemplputParams *TP)
 	wcsession *WCC = WC;
 		
 	which = GetTemplateTokenNumber(Target, TP, 2, 0);
-	if (WCC->Policy[which].loaded == 0) LoadExpirePolicy(which);
+	LoadExpirePolicy(which);
 	StrBufAppendPrintf(Target, "%d", WCC->Policy[which].expire_mode);
 }
 
 
-
 void LoadZoneFiles(void)
 {
 	icalarray *zones;
@@ -124,7 +130,7 @@ typedef struct _CfgMapping {
 	int type;
 	const char *Key;
 	long len;
-}CfgMapping;
+} CfgMapping;
 
 #define CFG_STR 1
 #define CFG_YES 2
@@ -197,11 +203,12 @@ CfgMapping ServerConfig[] = {
 	{CFG_STR, HKEY("c_xmpp_s2s_port")},
 	{CFG_STR, HKEY("c_pop3_fetch")},
 	{CFG_STR, HKEY("c_pop3_fastest")},
-	{CFG_YES , HKEY("c_spam_flag_only")},
-	{CFG_YES , HKEY("c_guest_logins")}
+	{CFG_YES, HKEY("c_spam_flag_only")},
+	{CFG_YES, HKEY("c_guest_logins")}
 };
 
 
+
 /*
  *  display all configuration items
  */
@@ -211,7 +218,7 @@ void load_siteconfig(void)
 	StrBuf *Buf;
 	HashList *Cfg;
 	long len;
-	int i;
+	int i, j;
 	
 	if (WCC->ServCfg == NULL)
 		WCC->ServCfg = NewHash(1, NULL);
@@ -224,43 +231,43 @@ void load_siteconfig(void)
 	if (GetServerStatus(Buf, NULL) != 1) {
 		StrBufCutLeft(Buf, 4);
 		AppendImportantMessage(SKEY(Buf));
+		FreeStrBuf(&Buf);
 		return;
 		
 	}
-	i = 0;
+	j = i = 0;
 	while (len = StrBuf_ServGetln(Buf),
 	       (len >= 0) && 
-	       (i <= (sizeof(ServerConfig) / sizeof(CfgMapping))) &&
 	       ((len != 3) || strcmp(ChrPtr(Buf), "000")))
 	{
-		Put(Cfg,
-		    ServerConfig[i].Key, 
-		    ServerConfig[i].len, 
-		    Buf, 
-		    HFreeStrBuf);
-		i++;
-		if (i <= sizeof(ServerConfig) / sizeof(CfgMapping))
+		if (i < (sizeof(ServerConfig) / sizeof(CfgMapping)))
+		{
+			Put(Cfg,
+			    ServerConfig[i].Key, 
+			    ServerConfig[i].len, 
+			    Buf, 
+			    HFreeStrBuf);
+			i++;
 			Buf = NewStrBuf();
-		else
-			Buf = NULL;			
-	}
-	if (strcmp(ChrPtr(Buf), "000")!=0)
-	{
-		/* WHOOOOPSI??? burn the lines we don't understand */
-		while ((len = StrBuf_ServGetln(Buf),
-			strcmp(ChrPtr(Buf), "000"))) {}
-		AppendImportantMessage(_("WARNING: Failed to parse Server Config; do you run a to new citserver?"), -1);
-		return;
+		}
+		else {
+			if (j == 0) {
+				syslog(LOG_WARNING, "The server sent more configuration data than this version of webcit is capable of changing.  Unknown configuration values will remain unchanged.");
+			}
+			j++;
+		}
 	}
 	FreeStrBuf(&Buf);
 
-	LoadExpirePolicy(sitepolicy);
+	LoadExpirePolicy(roompolicy);
+	LoadExpirePolicy(floorpolicy);
 	LoadExpirePolicy(mailboxespolicy);
+	LoadExpirePolicy(sitepolicy);
 }
 
 
 
-/**
+/*
  * parse siteconfig changes 
  */
 void siteconfig(void)
@@ -382,6 +389,73 @@ int ConditionalServCfgCTXStrBuf(StrBuf *Target, WCTemplputParams *TP)
 	else return 0;
 }
 
+/*----------------------------------------------------------------------------*
+ *              Displaying Logging                                            *
+ *----------------------------------------------------------------------------*/
+typedef struct __LogStatusStruct {
+	int Enable;
+	StrBuf *Name;
+}LogStatusStruct;
+
+void DeleteLogStatusStruct(void *v)
+{
+	LogStatusStruct *Stat = (LogStatusStruct*)v;
+
+	FreeStrBuf(&Stat->Name);
+	free(Stat);
+}
+
+void tmplput_servcfg_LogName(StrBuf *Target, WCTemplputParams *TP)
+{
+        LogStatusStruct *Stat = (LogStatusStruct*) CTX;
+	StrBufAppendTemplate(Target, TP, Stat->Name, 1);
+}
+
+int ConditionalServCfgThisLogEnabled(StrBuf *Target, WCTemplputParams *TP)
+{
+        LogStatusStruct *Stat = (LogStatusStruct*) CTX;
+	return Stat->Enable;
+}
+
+HashList *iterate_GetSrvLogEnable(StrBuf *Target, WCTemplputParams *TP)
+{
+        HashList *Hash = NULL;
+	StrBuf *Buf;
+	LogStatusStruct *Stat;
+	const char *Pos;
+	int Done = 0;
+	long len;
+	int num_logs = 0;
+
+        serv_puts("LOGP");
+        Buf = NewStrBuf();
+        StrBuf_ServGetln(Buf);
+        if (GetServerStatus(Buf, NULL) == 1) {
+                Hash = NewHash(1, Flathash);
+                while (!Done) {
+                        len = StrBuf_ServGetln(Buf);
+                        if ((len <0) || 
+                            ((len == 3) &&
+                             !strcmp(ChrPtr(Buf), "000")))
+                        {
+                                Done = 1;
+                                break;
+                        }
+			Stat = (LogStatusStruct*) malloc (sizeof(LogStatusStruct));
+			Pos = NULL;
+			Stat->Name = NewStrBufPlain(NULL, len);
+                        StrBufExtract_NextToken(Stat->Name, Buf, &Pos, '|');
+                        Stat->Enable = StrBufExtractNext_int(Buf, &Pos, '|');
+
+                        Put(Hash, IKEY(num_logs), Stat, DeleteLogStatusStruct); 
+			num_logs++;
+                }
+	}
+	FreeStrBuf(&Buf);
+	return Hash;
+}
+
+
 void 
 InitModule_SITECONFIG
 (void)
@@ -406,6 +480,10 @@ InitModule_SITECONFIG
 	RegisterConditional(HKEY("COND:EXPIRE:MODE"), 2, ConditionalExpire, CTX_NONE);
 	RegisterNamespace("EXPIRE:VALUE", 1, 2, tmplput_ExpireValue, NULL, CTX_NONE);
 	RegisterNamespace("EXPIRE:MODE", 1, 2, tmplput_ExpireMode, NULL, CTX_NONE);
+
+	RegisterConditional(HKEY("COND:SERVCFG:THISLOGENABLE"), 4, ConditionalServCfgThisLogEnabled, CTX_SRVLOG);
+	RegisterIterator("SERVCFG:LOGENABLE", 0, NULL, iterate_GetSrvLogEnable, NULL, DeleteHash, CTX_SRVLOG, CTX_NONE, IT_NOFLAG);
+	RegisterNamespace("SERVCFG:LOGNAME", 0, 1, tmplput_servcfg_LogName, NULL, CTX_SRVLOG);
 }
 
 void 
