@@ -111,6 +111,9 @@ const char *CtxNames[]  = {
 	"Context VCARD",
 	"Context SIEVE List",
 	"Context SIEVE Script",
+	"Context MailQ-Item",
+	"Context MailQ-Recipient",
+	"Context ServLogStatus",
 	"Context UNKNOWN"
 };
 
@@ -581,10 +584,10 @@ long GetTemplateTokenNumber(StrBuf *Target, WCTemplputParams *TP, int N, long df
 }
 
 
-/**
- * \brief puts string into the template and computes which escape methon we should use
- * \param Source the string we should put into the template
- * \param FormatTypeIndex where should we look for escape types if?
+/*
+ * puts string into the template and computes which escape methon we should use
+ * Source = the string we should put into the template
+ * FormatTypeIndex = where should we look for escape types if?
  */
 void StrBufAppendTemplate(StrBuf *Target, 
 			  WCTemplputParams *TP,
@@ -1054,6 +1057,11 @@ WCTemplateToken *NewTemplateSubstitute(StrBuf *Buf,
 				if (Handler->PreEvalFunc != NULL)
 					Handler->PreEvalFunc(NewToken);
 			}
+		} else {
+			LogTemplateError(
+				NULL, "Token ", ERR_NAME, &TP,
+				" isn't known to us.", 
+				NULL);
 		}
 		break;
 	case SV_GETTEXT:
