@@ -176,6 +176,7 @@ int tasks_RenderView_or_Tail(SharedMessageStatus *Stat,
 void display_edit_individual_task(icalcomponent *supplied_vtodo, long msgnum, char *from,
 			int unread, calview *calv)
 {
+	wcsession *WCC = WC;
 	icalcomponent *vtodo;
 	icalproperty *p;
 	struct icaltimetype IcalTime;
@@ -230,6 +231,11 @@ void display_edit_individual_task(icalcomponent *supplied_vtodo, long msgnum, ch
 	wc_printf("<div class=\"boxcontent\">\n");
 	wc_printf("<FORM METHOD=\"POST\" action=\"save_task\">\n");
 	wc_printf("<div style=\"display: none;\">\n	");
+
+	wc_printf("<input type=\"hidden\" name=\"go\" value=\"");
+	StrEscAppend(WCC->WBuf, WCC->CurRoom.name, NULL, 0, 0);
+	wc_printf("\">\n");
+
 	wc_printf("<input type=\"hidden\" name=\"nonce\" value=\"%d\">\n", WC->nonce);
 	wc_printf("<INPUT TYPE=\"hidden\" NAME=\"msgnum\" VALUE=\"%ld\">\n", msgnum);
 	wc_printf("<INPUT TYPE=\"hidden\" NAME=\"return_to_summary\" VALUE=\"%d\">\n",
@@ -383,7 +389,7 @@ void save_individual_task(icalcomponent *supplied_vtodo, long msgnum, char* from
 
 	if (supplied_vtodo != NULL) {
 		vtodo = supplied_vtodo;
-		/*
+		/**
 		 * If we're looking at a fully encapsulated VCALENDAR
 		 * rather than a VTODO component, attempt to use the first
 		 * relevant VTODO subcomponent.  If there is none, the
@@ -407,7 +413,7 @@ void save_individual_task(icalcomponent *supplied_vtodo, long msgnum, char* from
 
 	if (havebstr("save_button")) {
 
-		/* Replace values in the component with ones from the form */
+		/** Replace values in the component with ones from the form */
 
 		while (prop = icalcomponent_get_first_property(vtodo,
 							       ICAL_SUMMARY_PROPERTY), prop != NULL) {
@@ -497,7 +503,7 @@ void save_individual_task(icalcomponent *supplied_vtodo, long msgnum, char* from
 						   icalproperty_new_due(t)
 				);
 		}
-		/* Give this task a UID if it doesn't have one. */
+		/** Give this task a UID if it doesn't have one. */
 		syslog(9, "Give this task a UID if it doesn't have one.\n");
 		if (icalcomponent_get_first_property(vtodo,
 						     ICAL_UID_PROPERTY) == NULL) {
@@ -552,7 +558,7 @@ void save_individual_task(icalcomponent *supplied_vtodo, long msgnum, char* from
 		icalcomponent_free(encaps);
 	}
 
-	/*
+	/**
 	 * If the user clicked 'Delete' then explicitly delete the message.
 	 */
 	if (havebstr("delete_button")) {
@@ -570,7 +576,7 @@ void save_individual_task(icalcomponent *supplied_vtodo, long msgnum, char* from
 
 	/* Go back to wherever we came from */
 	if (ibstr("return_to_summary") == 1) {
-		do_template("summary_page");
+		display_summary_page();
 	}
 	else {
 		readloop(readfwd, eUseDefault);
@@ -720,7 +726,9 @@ int tasks_GetParamsGetServerCall(SharedMessageStatus *Stat,
 				 void **ViewSpecific, 
 				 long oper, 
 				 char *cmd, 
-				 long len)
+				 long len,
+				 char *filter,
+				 long flen)
 {
 	strcpy(cmd, "MSGS ALL");
 	Stat->maxmsgs = 32767;
@@ -747,6 +755,7 @@ InitModule_TASKS
 		tasks_GetParamsGetServerCall,
 		NULL,
 		NULL,
+		NULL,
 		tasks_LoadMsgFromServer,
 		tasks_RenderView_or_Tail,
 		tasks_Cleanup);
