@@ -1,19 +1,13 @@
 /*
- * Copyright (c) 1987-2011 by the citadel.org team
+ * Copyright (c) 1987-2012 by the citadel.org team
  *
  * This program is open source software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
- *
+ * it under the terms of the GNU General Public License, version 3.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 /*
@@ -21,11 +15,9 @@
 #define SERV_TRACE 1
  */
 
-
 #include "webcit.h"
 #include "webserver.h"
 
-extern int DisableGzip;
 long MaxRead = -1; /* should we do READ scattered or all at once? */
 
 /*
@@ -173,6 +165,9 @@ int StrBuf_ServGetln(StrBuf *buf)
 	const char *ErrStr = NULL;
 	int rc;
 	
+	if (!WCC->connected)
+		return -1;
+
 	FlushStrBuf(buf);
 	rc = StrBufTCP_read_buffered_line_fast(buf, 
 					       WCC->ReadBuf, 
@@ -401,13 +396,14 @@ int serv_read_binary(StrBuf *Ret, size_t total_len, StrBuf *Buf)
 	wcsession *WCC = WC;
 	size_t bytes_read = 0;
 	size_t this_block = 0;
-	int rc;
+	int rc = 6;
+	int ServerRc = 6;
 
 	if (Ret == NULL) {
 		return -1;
 	}
 
-	while (bytes_read < total_len) {
+	while ((bytes_read < total_len) && (ServerRc == 6)) {
 
 		if (WCC->serv_sock==-1) {
 			FlushStrBuf(Ret); 
@@ -415,7 +411,8 @@ int serv_read_binary(StrBuf *Ret, size_t total_len, StrBuf *Buf)
 		}
 
 		serv_printf("READ "SIZE_T_FMT"|"SIZE_T_FMT, bytes_read, total_len-bytes_read);
-		if ( (rc = StrBuf_ServGetln(Buf) > 0) && (GetServerStatus(Buf, NULL) == 6) ) 
+		if ( (rc = StrBuf_ServGetln(Buf) > 0) &&
+		     (ServerRc = GetServerStatus(Buf, NULL), ServerRc == 6) ) 
 		{
 			if (rc < 0)
 				return rc;
@@ -912,10 +909,12 @@ SessionDestroyModule_TCPSOCKETS
 {
 	FreeStrBuf(&sess->CLineBuf);
 	FreeStrBuf(&sess->ReadBuf);
+	sess->connected = 0;
 	sess->ReadPos = NULL;
 	FreeStrBuf(&sess->MigrateReadLineBuf);
 	if (sess->serv_sock > 0) {
 		syslog(LOG_DEBUG, "Closing socket %d", sess->serv_sock);
 		close(sess->serv_sock);
 	}
+	sess->serv_sock = -1;
 }
