@@ -1,19 +1,13 @@
 /*
- * Copyright (c) 1996-2011 by the citadel.org team
+ * Copyright (c) 1996-2012 by the citadel.org team
  *
  * This program is open source software.  You can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #include "webcit.h"
@@ -467,8 +461,10 @@ void tmplput_USER_BIO(StrBuf *Target, WCTemplputParams *TP)
 			if ( (StrLength(Buf)==3) && 
 			     !strcmp(ChrPtr(Buf), "000")) 
 				Done = 1;
-			else
+			else {
 				StrBufAppendBuf(BioBuf, Buf, 0);
+				StrBufAppendBufPlain(BioBuf, HKEY("\n"), 0);
+			}
 		}
 		StrBufAppendTemplate(Target, TP, BioBuf, 1);
 		FreeStrBuf(&BioBuf);
@@ -531,7 +527,7 @@ TRYAGAIN:
 	Stat.lowest_found = (-1);
 	Stat.highest_found = (-1);
 	/* Search for the user's vCard */
-	if (load_msg_ptrs("MSGS ALL||||1", &Stat, NULL) > 0) {
+	if (load_msg_ptrs("MSGS ALL||||1", NULL, &Stat, NULL) > 0) {
 		at = GetNewHashPos(WCC->summ, 0);
 		while (GetNextHashPos(WCC->summ, at, &HKLen, &HashKey, &vMsg)) {
 			Msg = (message_summary*) vMsg;		
@@ -806,19 +802,10 @@ void _display_edituser(void) {
 	display_edituser(NULL, 0);
 }
 
-void showuser(void)
-{
-	output_headers(1, 0, 0, 0, 1, 0);
-	do_template("user_show");
-	end_burst();
-}
-
-
 void 
 InitModule_USEREDIT
 (void)
 {
-	WebcitAddUrlHandler(HKEY("showuser"), "", 0, showuser, 0);
 	WebcitAddUrlHandler(HKEY("select_user_to_edit"), "", 0, _select_user_to_edit, 0);
 	WebcitAddUrlHandler(HKEY("display_edituser"), "", 0, _display_edituser, 0);
 	WebcitAddUrlHandler(HKEY("edituser"), "", 0, edituser, 0);
