@@ -3,21 +3,10 @@
  * persistent session to the Citadel server, handling HTTP WebCit requests as
  * they arrive and presenting a user interface.
  *
- * Copyright (c) 1996-2011 by the citadel.org team
+ * Copyright (c) 1996-2012 by the citadel.org team
  *
  * This program is open source software.  You can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * modify it under the terms of the GNU General Public License, version 3.
  */
 
 #define SHOW_ME_VAPPEND_PRINTF
@@ -31,7 +20,7 @@ StrBuf *csslocal = NULL;
 HashList *HandlerHash = NULL;
 
 void stuff_to_cookie(int unset_cookie);
-int GetConnected(void);
+extern int GetConnected(void);
 
 
 void PutRequestLocalMem(void *Data, DeleteHashDataFunc DeleteIt)
@@ -144,12 +133,7 @@ void wDumpContent(int print_standard_html_footer)
  */
 void output_headers(	int do_httpheaders,	/* 1 = output HTTP headers			  */
 			int do_htmlhead,	/* 1 = output HTML <head> section and <body> opener */
-
-			int do_room_banner,	/* 0=no, 1=yes,				     
-						 * 2 = I'm going to embed my own, so don't open the 
-						 *     <div id="content"> either.		   
-						 */
-
+			int do_room_banner,	/* 1 = include the room banner and <div id="content"></div> */
 			int unset_cookies,	/* 1 = session is terminating, so unset the cookies */
 			int suppress_check,	/* 1 = suppress check for instant messages	  */
 			int cache		/* 1 = allow browser to cache this page	     */
@@ -200,40 +184,24 @@ void output_headers(	int do_httpheaders,	/* 1 = output HTTP headers			  */
 	if (do_htmlhead) {
 		begin_burst();
 		do_template("head");
-
-		/* check for ImportantMessages (these display in a div overlaying the main screen) */
-		if (StrLength(WCC->ImportantMsg) > 0) {
-			wc_printf("<div id=\"important_message\">\n"
-				"<span class=\"imsg\">");
-			StrEscAppend(WCC->WBuf, WCC->ImportantMsg, NULL, 0, 0);
-			wc_printf("</span><br>\n"
-				"</div>\n"
-			);
-			StrBufAppendBufPlain(WCC->trailing_javascript,
-					     HKEY("setTimeout('hide_imsg_popup()', 5000);	\n"),
-					     0
-			);
-			FlushStrBuf(WCC->ImportantMsg);
-		}
 		if ( (WCC->logged_in) && (!unset_cookies) ) {
 			DoTemplate(HKEY("paging"), NULL, &NoCtx);
 		}
-
-		if (do_room_banner == 1) {
+		if (do_room_banner) {
 			tmplput_roombanner(NULL, NULL);
 		}
 	}
 
-	if (do_room_banner == 1) {
+	if (do_room_banner) {
 		wc_printf("<div id=\"content\">\n");
 	}
 }
 
 void output_custom_content_header(const char *ctype) {
-  hprintf("HTTP/1.1 200 OK\r\n");
-  hprintf("Content-type: %s; charset=utf-8\r\n",ctype);
-  hprintf("Server: %s / %s\r\n", PACKAGE_STRING, ChrPtr(WC->serv_info->serv_software));
-  hprintf("Connection: close\r\n");
+	hprintf("HTTP/1.1 200 OK\r\n");
+	hprintf("Content-type: %s; charset=utf-8\r\n",ctype);
+	hprintf("Server: %s / %s\r\n", PACKAGE_STRING, ChrPtr(WC->serv_info->serv_software));
+	hprintf("Connection: close\r\n");
 }
 
 
@@ -245,6 +213,7 @@ void http_redirect(const char *whichpage) {
 	hprintf("Location: %s\r\n", whichpage);
 	hprintf("URI: %s\r\n", whichpage);
 	hprintf("Content-type: text/html; charset=utf-8\r\n");
+	stuff_to_cookie(0);
 	begin_burst();
 	wc_printf("<html><body>");
 	wc_printf("Go <a href=\"%s\">here</A>.", whichpage);
@@ -255,11 +224,15 @@ void http_redirect(const char *whichpage) {
 
 
 /*
- * Output a piece of content to the web browser using conformant HTTP and MIME semantics
+ * Output a piece of content to the web browser using conformant HTTP and MIME semantics.
+ *
+ * If this function is called, it is expected that begin_burst() has already been called
+ * and some sort of content has been fed into the buffer.  This function will transmit a
+ * bunch of headers to the client.  end_burst() will add some headers of its own, and then
+ * transmit the buffered content to the client.
  */
 void http_transmit_thing(const char *content_type, int is_static)
 {
-
 	syslog(9, "http_transmit_thing(%s)%s", content_type, ((is_static > 0) ? " (static)" : ""));
 	output_headers(0, 0, 0, 0, 0, is_static);
 
@@ -283,14 +256,13 @@ void http_transmit_thing(const char *content_type, int is_static)
 void convenience_page(const char *titlebarcolor, const char *titlebarmsg, const char *messagetext)
 {
 	hprintf("HTTP/1.1 200 OK\n");
-	output_headers(1, 1, 2, 0, 0, 0);
-	wc_printf("<div id=\"banner\">\n");
+	output_headers(1, 1, 1, 0, 0, 0);
+	wc_printf("<div id=\"room_banner_override\">\n");
 	wc_printf("<table width=100%% border=0 bgcolor=\"#%s\"><tr><td>", titlebarcolor);
 	wc_printf("<span class=\"titlebar\">%s</span>\n", titlebarmsg);
 	wc_printf("</td></tr></table>\n");
 	wc_printf("</div>\n<div id=\"content\">\n");
 	escputs(messagetext);
-
 	wc_printf("<hr />\n");
 	wDumpContent(1);
 }
@@ -826,7 +798,13 @@ void display_default_landing_page(void) {
 	if (WCC && WCC->serv_info && WCC->serv_info->serv_supports_guest) {
 		/* default action */
 
-		if (default_landing_page) {
+		if (havebstr("go")) {
+			syslog(9, "Explicit room selection: %s", bstr("go"));
+			StrBuf *teh_room = NewStrBufPlain(bstr("go"), strlen(bstr("go")));
+			smart_goto(teh_room);
+			FreeStrBuf(&teh_room);
+		}
+		else if (default_landing_page) {
 			http_redirect(default_landing_page);
 		}
 		else {
@@ -885,7 +863,6 @@ void tmplput_importantmessage(StrBuf *Target, WCTemplputParams *TP)
 	if (WCC != NULL) {
 		if (StrLength(WCC->ImportantMsg) > 0) {
 			StrEscAppend(Target, WCC->ImportantMsg, NULL, 0, 0);
-			FlushStrBuf(WCC->ImportantMsg);
 		}
 	}
 }
@@ -919,6 +896,7 @@ InitModule_WEBCIT
 {
 	char dir[SIZ];
 	WebcitAddUrlHandler(HKEY("blank"), "", 0, blank_page, ANONYMOUS|COOKIEUNNEEDED|ISSTATIC);
+	WebcitAddUrlHandler(HKEY("landing"), "", 0, display_default_landing_page, ANONYMOUS|COOKIEUNNEEDED);
 	WebcitAddUrlHandler(HKEY("do_template"), "", 0, url_do_template, ANONYMOUS);
 	WebcitAddUrlHandler(HKEY("sslg"), "", 0, seconds_since_last_gexp, AJAX|LOGCHATTY);
 	WebcitAddUrlHandler(HKEY("ajax_servcmd"), "", 0, ajax_servcmd, 0);
@@ -994,6 +972,10 @@ SessionDetachModule_WEBCIT
 	else
 		FlushStrBuf(sess->WBuf);
 	FlushStrBuf(sess->HBuf);
+	if (StrLength(sess->ImportantMsg) > 0) {
+		FlushStrBuf(sess->ImportantMsg);
+	}
+
 }
 
 void 
