@@ -1,19 +1,13 @@
 /*
- * Copyright (c) 1996-2011 by the citadel.org team
+ * Copyright (c) 1996-2012 by the citadel.org team
  *
  * This program is open source software.  You can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #include "webcit.h"
@@ -86,7 +80,6 @@ int main(int argc, char **argv)
 	const char *basedir = NULL;
 	char uds_listen_path[PATH_MAX];	/* listen on a unix domain socket? */
 	const char *I18nDumpFile = NULL;
-	int rv = 0;
 
 	WildFireInitBacktrace(argv[0], 2);
 
@@ -237,26 +230,21 @@ int main(int argc, char **argv)
 
 	/* Tell 'em who's in da house */
 	syslog(1, "%s", PACKAGE_STRING);
-	syslog(1, "Copyright (C) 1996-2011 by the citadel.org team");
+	syslog(1, "Copyright (C) 1996-2012 by the citadel.org team");
 	syslog(1, " ");
 	syslog(1, "This program is open source software: you can redistribute it and/or");
-	syslog(1, "modify it under the terms of the GNU General Public License as published");
-	syslog(1, "by the Free Software Foundation, either version 3 of the License, or");
-	syslog(1, "(at your option) any later version.");
+	syslog(1, "modify it under the terms of the GNU General Public License, version 3.");
 	syslog(1, " ");
 	syslog(1, "This program is distributed in the hope that it will be useful,");
 	syslog(1, "but WITHOUT ANY WARRANTY; without even the implied warranty of");
 	syslog(1, "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the");
 	syslog(1, "GNU General Public License for more details.");
 	syslog(1, " ");
-	syslog(1, "You should have received a copy of the GNU General Public License");
-	syslog(1, "along with this program.  If not, see <http://www.gnu.org/licenses/>.");
-	syslog(1, " ");
-
 
 	/* initialize various subsystems */
 
 	initialise_modules();
+	initialise2_modules();
 	InitTemplateCache();
 	if (DumpTemplateI18NStrings) {
 		FILE *fd;
@@ -274,7 +262,7 @@ int main(int argc, char **argv)
 			syslog(1, "***********************************************\n");
 			return -1;
 		}
-		rv = fwrite(ChrPtr(I18nDump), 1, StrLength(I18nDump), fd);
+		fwrite(ChrPtr(I18nDump), 1, StrLength(I18nDump), fd);
 		fclose(fd);
 		return 0;
 	}
